package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````G1<``#0```"DL0````0`!30`(``)
M`"@`&P`:``$``'!8G@``6)X``%B>```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!DG@``9)X```4```````$`
M`0```(2M``"$K0$`A*T!`+P"``#4$@``!@```````0`"````C*T``(RM`0",
MK0$`*`$``"@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DA*T`
M`(2M`0"$K0$`?`(``'P"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50`T=PQA_2@Y(D0DYN6*F`-NV[[.)A$```!0````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(TXH!)%B@0("%````!1````50``
M`%H```!;````8@```&,```!D````9@```&<`````````:0```&H```!K````
M;0```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_Y`ZX
MC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>O
MS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)````
M``````````````````````"X$@````````,`"P```````+`!```````#`!8`
MMP(`````````````$@```&4#`````````````!(````Y`P`````````````B
M````?@,`````````````$0```"D$`````````````!(````1````````````
M```@````*@(`````````````$@````L#`````````````!(```!6`P``````
M```````2````$0$`````````````$@```)P#`````````````!$```"T````
M```````````2````T@(`````````````$@```(,!`````````````!(```"^
M`@`````````````2````A```````````````$@````P!`````````````!(`
M``#9`@`````````````2````FP(`````````````$@```&$"````````````
M`!(````Y`@`````````````2````<@(`````````````$@```'\"````````
M`````!(````!`0`````````````1````9P$`````````````$@```.,`````
M`````````!$````U`0`````````````2````$@,`````````````$@````0#
M`````````````!$````;`P`````````````2````P@``````````````$@``
M`+$!`````````````!(````B`@`````````````2````G@$`````````````
M$@```/("`````````````!(````*`@`````````````2````J@$`````````
M````$@```&P#`````````````!(```!#`0`````````````2````+0``````
M````````(````)0"`````````````!(```!+`@`````````````2````J0(`
M````````````$@```+P!`````````````!$```!D```````````````2````
M*`,`````````````$@```),``````````````!(````1`@`````````````2
M````2`,`````````````$@```)\``````````````!(```!<`0``````````
M```2````>0(`````````````$@```+`"`````````````!(````B`0``````
M```````2````5@``````````````$@```!8!`````````````!(```"3`0``
M```````````2````Q`(`````````````$@```/```````````````!(```"-
M`@`````````````2````7@,`````````````$@```*("`````````````!(`
M``!U`0`````````````2````<P``````````````$@```'\#````````````
M`"$````O`P`````````````2````U```````````````$@```%,!````````
M`````!(````\```````````````@````@`,`````````````$0```/H"````
M`````````!(```!0`@`````````````2````AP(`````````````$@````0"
M`````````````!(```#G`@`````````````2````6`(`````````````$@``
M`/`!`````````````!(```#>`P``6,`!```````0`!<`,@0```5>``!0````
M$@`-```$``"H7@```````!(`#@!7!```Q5,``(@'```2``T`>0,``.D5``"T
M`0``$@`-``8$``#)3@``!````!(`#0#/`P``0+`!```````0`!<`Q00``,U.
M``"0`0``$@`-`+\$``"X$@```````!(`"P#R!```35L``+@"```2``T`PP,`
M`$"P`0``````$``7`#X$``!=4```%@```!(`#0!Q!```L%X```0````1``\`
M\0,``%C``0``````$``7`.D#``!8P`$``````!``%P"]!```L4T``#@````2
M``T`T@0``"E3``"<````$@`-`.0$``"Y4@``8````!(`#0!D!````+`!````
M```0`!8`2P0``'50``#`````$@`-`+P#``!`L`$``````!``%@"F!```/+`!
M``0````1`!8`]@,``*5>```"````$@`-`)8$``!E7@``0````!(`#0!J!```
MG1<````````2``T`9@0```"P`0``````(``6`!<$```94P``$````!(`#0#=
M`P``6,`!```````0`!<`@`0``#5.``"4````$@`-`+`$```U40``A`$``!(`
M#0``;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E
M<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P
M97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X
M=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T
M<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`
M<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L
M7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3
M`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`
M<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M
M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O
M+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L
M;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F
M;W)K`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N
M;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R9'5P
M`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?
M8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?
M7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`
M<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK
M`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N
M=FER;VX`;&0M;&EN=7@M87)M:&8N<V\N,P!?7W-T86-K7V-H:U]G=6%R9`!L
M:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?
M`%]?8G-S7V5N9%]?`%]?96YD7U\`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R
M7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER
M`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C
M7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`
M>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N
M=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT````````
M``(``@`"``(``@````,``@`"``(`!`````(````"```````"``(``@`"``(`
M`@````````````(``@`"```````#`````@`#``(``@```````@`"``(`````
M``(````#``(```````(``@````````````(````"``(``@```````@`"````
M``````(``@`"``(``P`"``(``P`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0````$``0"(`P``
M$````"`````4:6D-```$``@%`````````0`!`.`!```0````(````!1I:0T`
M``,`"`4````````!``$`+P(``!``````````%&EI#0```@`(!0```````(2M
M`0`7````B*T!`!<```#`KP$`%P```.BO`0`7````\*\!`!<````$L`$`%P``
M``RP`0`7````$+`!`!<````8L`$`%P```!RP`0`7````(+`!`!<````DL`$`
M%P```"BP`0`7````,+`!`!<````TL`$`%P```#RP`0`7````Q*\!`!4%``#(
MKP$`%0@``,RO`0`5#0``T*\!`!40``#4KP$`%1H``-BO`0`5'```W*\!`!4?
M``#@KP$`%2H``.2O`0`5+@``[*\!`!4X``#TKP$`%4(``/BO`0`51P``_*\!
M`!5(``#`K@$`%@,``,2N`0`6!```R*X!`!8%``#,K@$`%@<``-"N`0`6"0``
MU*X!`!8*``#8K@$`%@L``-RN`0`6#```X*X!`!8.``#DK@$`%@\``.BN`0`6
M$0``[*X!`!82``#PK@$`%A,``/2N`0`6%```^*X!`!85``#\K@$`%A8```"O
M`0`6%P``!*\!`!88```(KP$`%AD```RO`0`6&P``$*\!`!8=```4KP$`%AX`
M`!BO`0`6(```'*\!`!8A```@KP$`%B(``"2O`0`6(P``**\!`!8D```LKP$`
M%B4``#"O`0`6)@``-*\!`!8G```XKP$`%B@``#RO`0`6*0``0*\!`!8J``!$
MKP$`%BL``$BO`0`6+```3*\!`!8M``!0KP$`%B\``%2O`0`6,```6*\!`!8Q
M``!<KP$`%C(``&"O`0`6,P``9*\!`!8T``!HKP$`%C4``&RO`0`6-@``<*\!
M`!8W``!TKP$`%CD``'BO`0`6.@``?*\!`!8[``"`KP$`%CP``(2O`0`6/0``
MB*\!`!8^``",KP$`%C\``)"O`0`60```E*\!`!9!``"8KP$`%D0``)RO`0`6
M10``H*\!`!9&``"DKP$`%DD``*BO`0`62@``K*\!`!9+``"PKP$`%DP``+2O
M`0`630``N*\!`!9.``"\KP$`%D\```A`+>E(`0#K"("]Z`3@+>4$X)_E#N"/
MX`CPON7@FP$``,:/XAG*C.+@^[SE`,:/XAG*C.+8^[SE`,:/XAG*C.+0^[SE
M`,:/XAG*C.+(^[SE`,:/XAG*C.+`^[SE`,:/XAG*C.*X^[SE`,:/XAG*C.*P
M^[SE`,:/XAG*C.*H^[SE`,:/XAG*C.*@^[SE`,:/XAG*C.*8^[SE`,:/XAG*
MC.*0^[SE`,:/XAG*C.*(^[SE`,:/XAG*C.*`^[SE`,:/XAG*C.)X^[SE>$?`
M1@#&C^(9RHSB;/N\Y0#&C^(9RHSB9/N\Y7A'P$8`QH_B&<J,XEC[O.4`QH_B
M&<J,XE#[O.4`QH_B&<J,XDC[O.4`QH_B&<J,XD#[O.4`QH_B&<J,XCC[O.4`
MQH_B&<J,XC#[O.4`QH_B&<J,XBC[O.4`QH_B&<J,XB#[O.4`QH_B&<J,XAC[
MO.4`QH_B&<J,XA#[O.4`QH_B&<J,X@C[O.4`QH_B&<J,X@#[O.4`QH_B&<J,
MXOCZO.4`QH_B&<J,XO#ZO.4`QH_B&<J,XNCZO.4`QH_B&<J,XN#ZO.4`QH_B
M&<J,XMCZO.4`QH_B&<J,XM#ZO.4`QH_B&<J,XLCZO.4`QH_B&<J,XL#ZO.4`
MQH_B&<J,XKCZO.4`QH_B&<J,XK#ZO.4`QH_B&<J,XJCZO.4`QH_B&<J,XJ#Z
MO.4`QH_B&<J,XICZO.4`QH_B&<J,XI#ZO.5X1\!&`,:/XAG*C.*$^KSE`,:/
MXAG*C.)\^KSE`,:/XAG*C.)T^KSE`,:/XAG*C.)L^KSE`,:/XAG*C.)D^KSE
M`,:/XAG*C.)<^KSE`,:/XAG*C.)4^KSE`,:/XAG*C.),^KSE`,:/XAG*C.)$
M^KSE`,:/XAG*C.(\^KSE`,:/XAG*C.(T^KSE`,:/XAG*C.(L^KSE`,:/XAG*
MC.(D^KSE`,:/XAG*C.(<^KSE`,:/XAG*C.(4^KSE`,:/XAG*C.(,^KSE`,:/
MXAG*C.($^KSE`,:/XAG*C.+\^;SE`,:/XAG*C.+T^;SE`,:/XAG*C.+L^;SE
M`,:/XAG*C.+D^;SE`,:/XAG*C.+<^;SE`````/"UB;!83%E+?$0%D`21!:@#
MD@2IYE@#JC-H!Y/_]T3O4TI42Z)8X%@11@3P'_Q22^-8'W@`+VG04$OE6"AH
M__?8[Y#X#C0"1BAH0_`"`X+X#C3_]\[O!9L%,[/Q@$^0^`XD0O`!`H#X#B1I
MTI@`!"?_]][N0DH$G7I$0DL1:'M$04HL:'I$0V#`Z0(2/TL%FGM$!&`!*L/I
M`7`*W>L9`/$,`07K@@53^`1+JT)!^`1/^=$W3P+Q@$$`)`,Q?T0`E$#X(4`#
M1CUI`S(R22A&>43_]R[O!$9PLR]-!J]]1"AI__=\[BU(.49X1`/P/?GHL2M+
M>T08:?_W1.[_]P[O!YHS:"!&FD(JT0FP\+W_]X3N)$IZ1!!A(+/_]RSN%TOE
M6"AH__=F[X#X@7:'Y^AH:+$$\'3[W.<X:?_W,.\$1LOG&4L:2.%8>$3_]\SN
M&$@Y1GA$`_`)^>A@`"C)T.CG__<D[@$@__>4[L"8`0`8`0``.`$``$`!```D
M`0``(`$``-B9`0"*2P``B$L``,B9`0"<F0$`+S<``'R9`0#82```9ID!`$:9
M`0`P`0``^DD```Q(``!/\``+3_``#@*\:D8$M`&TW_@DH`BCFD3?^"#`6O@,
MP$WX!,T&2UKX`S`&2%KX``#_]SSN__?J[N"6`0`,`0``-`$``#P!```4,)_E
M%""?Y0,PC^`"()/G``!2XQ[_+P$7___JP)8!`"P!```&2`=+>$0'2GM$@T)Z
M1`/0!4O36`.Q&$=P1P"_,)@!`"R8`0"<E@$`%`$```A("4MX1`E*>T09&GI$
MB1`!Z]%Q21`#T`5+TU@#L1A'<$<`OP28`0``F`$`<)8!`$0!```(M0I+"DI[
M1'I$&WAKN0E+TU@CL0A+>T08:/_W-NW_][__!DL!(GM$&G`(O<Z7`0!`E@$`
M$`$``(*7`0"NEP$`Q.<`OP````#?^'P^`/%`#-_X>"XMZ?!/>T2M]3]]`/&`
M"`WQ<`I/\``.&I";6%!&&Y,;:+V37/@$'``E7/@(?`SQ"`S@1<#X!.!/ZA$B
M3^H19D_J`2,"]']$`)-$Z@8"`99%Z@X#W>D`14_J`6%"Z@$"3_``!03T?P1#
MZ@4#0NH$`C^ZP.D"(P#Q$`!`^!!\T=$-\6@,"O7\?LWX`*!D1OSI`HG4Z1(C
M`"'4Z1QGU.D&18+J!@J#Z@<+4D9B0(CJ`@1;1FM`(AF)Z@,%X`_T14#J10!`
MZ@($($;,Z2`!WM$:FP`D`"7=^`"@(48J1M/I`&?-Z0`2S>D&$O(.`)+3Z002
M?0'3Z0*\1>K69=KI`(ET`<WI!!+3Z08!T^D((P"5S>D"9\WI$B/[#@&3#_9(
M4]/I`"/-Z0H!$NL(`LWI%KR01MWI!"-"0!9&W>D`(P`C(D/=Z1)%%.L(!*!&
M7$8T0!CK`@@F1F1&I`<'E%Q&!YJ@"-WI"D5"ZIL"!Y)T0$#JC'`F1EQ&H@<&
MDMWI!D5B1I$(%NL(!@1##4-/\``,LT8G1JA&.$;-Z0AX3^I,%@`D`"'-Z0`T
MVND"(T_JW&4!EMWI!&?-Z08!`9F&Z@`(0>K;80&1#$8/]J!!T>D``8`8`D;=
MZ0(!3^I+$0"1`.H(`(!&W>D*`8;J"`;=Z0*)@!@"1MWI``$@0RE#S>D``9`9
M`)E*1I<'3_``"4(8W>D"`4?JF`=/ZDD>D$:&!XT(1NH'`D?J!0/:Z01%3NK8
M;A9&'T;=Z0@C<$;-Z0QG3^K987)`S?@$X$_J2![-^`#@%D8&Z@L"#_801]?I
M`&=/ZIP#-ADT1MWI!F=60#)&W>D$9S89-$;=Z0!G!D,/0\WI`&>@&`"93^J,
M=T?JFP<`(D08`"%'Z@,,`",@1LWI`"/:Z09%2P$!DT_JBW8/]KPST^D`(T;J
M!PO-Z0B\$AEK0<WI#B,!F]WI"$5#ZM!C`9.;1MWI#",61F9`'T9O0``C-4;-
MZ0PC!>H(`@?J"0/=Z0Y%W>D&9Z09?4'=Z0QG5D!?0$_JF0,R1D8!`):F&$7K
M!P?-Z09GW>D`9T_JB74`)T7JF`5&Z@L&3^J(=-WI!KR\1D7J`PA$Z@4'`",`
M),WI!C1C1AOK!@M;`0>3/D8/]A@ST^D`(T=&!YM/ZMMHS>D`O$CJ3!A#ZMMC
MW>D(O-KI"$5/\``,S>D.9P`EI!A:1G)`W>D,9P)`S>D,O#89!Y.+"$_P``DT
M1EY&W>D`O%9`,D9>1A3K`@MV`0:6`";-Z0A6W>D&9XP'"91/ZDD71NH(!AOK
M!@0)GJ!&1NJ0#H0'S?@DX`B4=D;=Z0@!1^K89]KI"D490P_V@"/3Z0`C,$,&
MEQ(93^I(%FM!S>D((]WI#B,`)<WI#@$I1@`G%$9$0!!&HT;=Z0`TW>D(10OJ
M`PM:1MWI#+S-Z1`!3^K9;!3K"P3-^!S`@.H""Q3K"PO=Z09%-$,F1@&<H0<`
MG*((&^L&!-WI`+PF1EQ&0>J;`:`'9$9"ZHQRHPA`Z@(+VND,14'J`PP/]O02
MTND`$LWI"+Q[`0D90^K68VI!S>D&$MWI#@$`(=WI"$5/\``,`9/-Z0P!`D;=
MZ1`!8D#=Z09%`NH(`LWI!F<D&-WI#`%Q`0"1W>D`9U!`3^J)<1Y#`D:@&$'J
MF`&$&4_JF0-/ZHAP`"*C1D'J`PC:Z0Y%`"/-Z0`C3^I,$P&30.H!!P_V;!/3
MZ0`C048X1MWI"&<2&<WI"`%K011&,D8=1@&;0D!#ZMMC`9.81CM&2T#=Z0P!
M`"?-Z0YG`!G=Z09G:4$$1A]`#4;=Z0X!%D!Y0'!`(!@+1D_J2Q$`D47K`P'=
MZ0!GS>D,`4;J"`;=Z0:)3$9/\``)H0?=Z0Q%0>J8`4_JV6ZD&=WI!E;-^`3@
MH$:S"*@'0>H#!]KI$$4/]M0#T^D`(T#J`08Y1D_J21<2&3!&:T'=Z0A%S>D&
M(PI&S>D0`55`W>D($G1`!>H,`P`B1^K89P"7S>D,$@3J"P+=Z0X!3^I(%MWI
M!D4`)R0834'=Z0P!4$!90$_JG`,"1J`81>L!`=WI`$7-Z08!3^J,<31#0>J;
M`4'J`PP`(B9&W>D&10`CS>D&(Z09>P$'DT_JBW`F1@_V/`/3Z0`CVND214#J
M`0O-Z0B\3_``#!(9S>D`9VM!S>D4(P>;`"7=Z1`20^K68]WI"&<'DPQ&=$`F
M1@Q&W>D,`0;J"`+-Z0Y%W>D41=WI`&<D&-WI#@%Q`5!`!I%/ZHEQW>D&9P)&
MH!A!ZI@!'D-/ZID#A!E/ZHAP0.H!!T'J`PBC1@_RN'+2Z0`2VND414_J3!-#
MZMMC/D8)&0>3:D%'1@Q&W>D(`15&F$;-Z0AG`D8+1@`AS>D,`=WI#@%R0'M`
MW>D`9P`9:4$?0`1&%D`-1MWI#`%Y0'!`(!@+1D_J2Q$&D47K`P'=Z09GS>D.
M`4;J"`;=Z0")3$9/\``)H0?=Z0Y%0>J8`4_JV6ZD&=WI`%;-^`3@H$:S"*@'
M0>H#!]KI%D4/\AAST^D`(T#J`08Y1D_J21<2&3!&:T'=Z0A%S>D&(PI&S>D0
M`55`W>D($G1`!>H,`P`B1^K89P"7S>D.$@3J"P+=Z0P!3^I(%MWI!D4`)R08
M34'=Z0X!4$!90$_JG`,"1J`81>L!`=WI`$7-Z08!3^J,<31#0>J;`4_JBW!!
MZ@,,)D;=Z09%0.H!"P`BI!G-Z0B\`"/-Z08C)D9[`=KI&$5/\``,!Y,/\G!C
MT^D`(\WI`&<2&6M!S>D4(P>;`"7=Z1`20^K68]WI"&<'DPQ&=$`F1@Q&!NH(
M`LWI#$7=Z0X!W>D`9]WI%$4D&-WI#`%Q`0:1W>D&9U!`3^J)<1Y#`D:@&$'J
MF`&$&4_JF0-/ZHAP0>H#"*-&0.H!!]KI&D5/ZDP3#_+T4M+I`!)#ZMMC/D8'
MDPD91T9J09A&#$;=Z0@!%4;-Z0AG`D8+1@`AS>D.`=WI#`%R0'M`W>D`9P`9
M:4$?0`1&%D`-1MWI#@%Y0'!`(!@+1D_J2Q$&D47K`P'=Z09GS>D,`4;J"`;=
MZ0")3$9/\``)H0?=Z0Q%0>J8`4_JV6ZD&=WI`%:@1K,(J`=!Z@,'VND<10_R
M8%/3Z0`C0.H!!CE&3^I)%Q(9,$9K0=WI"$7-Z08C1^K89\WI$`$*1@"754#=
MZ0@2=$`%Z@P#`"+-^`3@3^I(%LWI#!($Z@L"W>D.`0`GW>D&120834'=Z0P!
M4$!90$_JG`,"1J`81>L!`=WI`$7-Z08!3^J,<31#0>J;`4'J`PP`(B9&W>D&
M10`CS>D&(Z09>P$'DT_JBW`F1@_RQ$/3Z0`CVND>14#J`0O-Z0B\3_``#!(9
MS>D`9VM!S>D4(P>;`"7=Z1`20^K68]WI"&<'DPQ&=$`F1@Q&!NH(`MWI#`'-
MZ0Y%W>D`9]WI%$4D&-WI#@%Q`0:1W>D&9U!`3^J)<1Y#`D:@&$'JF`&$&4_J
MF0-/ZHAP0>H#"*-&0.H!!]KI($5/ZDP3#_(X0M+I`!)#ZMMC/D8'DPD91T9J
M09A&#$;=Z0@!%4;-Z0AG`D8+1G)`>T``(=WI`&?-Z0P!W>D.`1]`%D``&6E!
M!$8-1MWI#`%Y0'!`(!@+1D_J2Q$&D47K`P'=Z09GS>D.`4;J"`;=Z0")3$9/
M\``)H0?=Z0Y%0>J8`4_JV6ZD&=WI`%;-^`3@H$:S"*@'0>H#!]KI(D7HH]/I
M`"-`Z@$&.49/ZDD7$ADP1FM!W>D(1<WI$",*1LWI#@%50-WI"!)T0`7J#`,`
M(D?JV&<`E\WI!A($Z@L"W>D,`4_J2!;=Z1!%`"<D&$U!W>D&`5!`64!/ZIP#
M`D:@&$7K`0'=Z0!%S>D(`4_JC'$T0T'JFP%!Z@,,`"(F1MWI"$4`(\WI`".D
M&7L!`9-/ZHMP)D;"H]/I`"/:Z21%0.H!"\WI"+P2&=WI#KQK0<WI$",!F]WI
M"$5:1D/JUF,!DV)`&$9C1D_P``QK0,WI#+P"Z@@"W>D&O`/J"0/=Z1!%%.L+
M!$7K#`7=Z0R\B^H""XSJ`PP;ZP0"3^I&$P"33.L%`]WI`+P`)``E2^H`"RE&
M($;-Z0`!$NL+`$_JF`%/ZHEU`)%#\0`!1>J8!4_JF0,`E0&3"D9/ZHAT`4:`
M1LWI$!+=Z0`!3_``"=KI)B,@0RE#S>D&`0`@`"'-Z0`!3^K880"1CJ'1Z0`!
M3^I)%47JV&4`E8`83^I(%%E!W>D((\WI%`'=Z08!@^H!#(+J``L`(]WI%`'-
MZ0XC"^H&`@SJ!P/=Z0R\$.L+`$'K#`'=Z0Z\B^H""XSJ`PP;ZP`"3^K98P&3
M3.L!`]WI`+RY"$_P``Q+Z@0+$NL+!$/Q``6[!T/JE@,!DZ-&S>D411A&LP<`
MD]WI`$7:Z2@C#4,$0RY&($8Q1MWI!E;-Z0@!94`N1F6EU>D`1:0874$@1MWI
M$#0I1MWI#D5S0"0834%/ZDP10>K;82)&`9$>1@Q&3^I+$0"1D!G=Z0`C1?$`
M`4_JB75/ZID#(D-%ZI@%AAA/ZHAT3_``"$'Q``=%Z@,)049$Z@4(W>D(1<WI
M#(DP1H3J"`3=Z12)VNDJ(T_JC'6(Z@0(S>D.9T\!1>J;!41&#_((&=GI`(E'
MZM9G`)<8ZP((!II)ZP,)=@$8ZP("2?$``Q+K!`A#\0`)RPX!DT_JBW3=Z0`C
M3^J<`T_P``PR0QCK`@9%Z@,(2?$`!\WI$&=$Z@4'0T;:Z2Q%LT8Z1LWI!B,J
MH]/I`"/=Z0R)$AF(Z@<(W>D.9Q1&")IK08;J"`:B&$_J3!1$ZMMDL$8!E$/Q
M``,F1D_J2Q0`E!+K"`1#\0`%W>D`(X\'BP@R0T?JD`<4ZP((3^J`=D7Q``D`
M(41&0$9-1LWI#D5'Z@,%1NH'!-KI+B,G1JA&W>D&14_JC'7-Z0AX1>J;!0_R
M(`G9Z0")?$#=Z1!G3P$8ZP((#)H-X*_S`("9>8):`````*'KV6X`````\)4!
M`!@!``"&Z@0&2>L#"1CK`@)'ZM!G-$9)\0`#$NL$"`"70_$`"<L.`9-&`=WI
M`"-/ZHMT3^J<`T_P``PR0QCK`@9$Z@4(2?$`!T7J`PG-Z1!G0D9+1MWI"(G:
MZ3!%LT;-Z0PCB.H""`_VS&/3Z0`CW>D.9X\'$AE'ZI`':T&&Z@@&%$8&FK!&
MHAA/ZDP41.K;9$/Q``,!E"9&3^I+%`"4$NL(!$/Q``7=Z0`CBP@`(3)#A@<4
MZP((1?$`"=WI#$5`1LWI#HE&Z@<(1^H#"83J"`3:Z3(CS>D&B4_JC'4/]E1I
MV>D`B47JFP7=Z1!G3P$8ZP((")J&Z@0&2>L#"1CK`@)'ZM!G-$9)\0`#$NL$
M"`"70_$`"<L.`9-&`=WI`"-/ZHMT3^J<`T_P``PR0QCK`@9%Z@,(2?$`!\WI
M$&=$Z@4'0T;:Z31%LT8Z1LWI"",/]N13T^D`(]WI!HD2&8CJ!PC=Z0YG%$8,
MFFM!ANH(!J(83^I,%$3JVV2P1D/Q``,!E"9&3^I+%`"4$NL(!$/Q``7=Z0`C
MCP>+"#)#1^J0!Q3K`@A/ZH!V1?$`"0`A1$9`1DU&S>D.14?J`P5&Z@<$VNDV
M(R=&J$;=Z0A%3^J,=<WI#'A%ZIL%#_9<6=GI`(E\0-WI$&=/`1CK`@@&FH;J
M!`9)ZP,)&.L"`D?JT&<T1DGQ``,2ZP0(`)=#\0`)RPX!DT8!W>D`(T_JBW1/
MZIP#3_``##)#&.L"!D3J!0A)\0`'1>H#"4)&VNDX14M&W>D,B<WI!B.S1HCJ
M`@@/]NA#T^D`(\WI$&<2&=WI#F=K08\'%$8(FH;J"`9'ZI`'HAA/ZDP41.K;
M9+!&`91#\0`#)D9/ZDL4`)02ZP@$0_$`!=WI`".+"``A,D.&!Q3K`@A&Z@<$
M1?$`"4?J`P7-Z0Z)0$8G1JA&W>D&14_JC'7:Z3HC1>J;!<WI"'A\0`_V:$G9
MZ0")W>D09T\!&.L""`R:ANH$!DGK`PD8ZP("1^K09S1&2?$``Q+K!`@`ET/Q
M``G+#@&33^J+=-WI`"-/ZIP#1>H##$3J!0M&`=WI"$4R0\WI#+P8ZP(&A.H+
M!-KI/".%Z@P%#_8`3-SI`+Q)\0`'W>D.B1OK`@L&FDSK`PR(Z@0(&^L"`XGJ
M!0ED1D3Q``3-Z0Z)&D8`)2-&`"3-Z0!%]`X`E`Z<3^I&&,WI$&<`)Q+K!`M/
MZD<90_$`#$GJUFG[#LWX`)`!DXT'W>D`(T7JD`6$!XL(0NH(`@`A&^L""$SQ
M``G-Z0Z)0$9%Z@,)1.H%"-KI/B--1MWI$*M$1MWI#(G-Z09%3^I!&XCJ!`@/
M]E0UU>D`18KJ"`I+ZM!KI!A=0=!&(D8(G``C3^I`&A093_```D7Q``7-Z0`C
M%.L(`D_JT&-<K`"31?$``\WX`+"01KT'F4;4Z0`T1>J6!<WI%#3+#@&3M`?=
MZ0`CNPA"Z@H"3_``"E=&1>H#"ACK`@A)\0`)S>D0B43J!0E41MWI!JM&1DM&
MS>D(-(KJ"0K=Z10CW>D.14_J@7G01@_VN"O;Z0"KA.H(!$GJD`D:ZP(*#)I+
MZP,+H$8`(P`DS>D`-'L!`9,:ZP(#2_$`!)I&`9NC1O0.0^K68P&3<P$`D]WI
M`"-$ZD<4&NL("LWX`)!"Z@0"2_$`"QKK`@1/ZI$#`9-+\0`%(D;-Z11%W>D`
M14_J@'A>J0`C1.H(!$7J"071Z0`!3^I#&Z!&J4;=Z0A%2^K2:\WI#(E/ZD(:
MA.H(!`_V%"G9Z0")O0<8ZP`(!IA)ZP$)S>D`B=WI$(E%ZI8%A$;=Z0`!B.H$
M",WX`+`0ZPP`#?7`?$'Q``%$1A#K!`A/ZH9T0?$`"=D.`9'=Z0`!N0A`Z@H`
M&.L`"@B82?$`"]%&VD;-Z1":3_``"D7J`0M71D3J!0K=Z0Q%3D;-Z0ZK>0'<
MZ0")A>H+!0_VC!S<Z0"\A.H*!$'JUF$!D1OK"`M/ZI,!3.L)#-A&W>D4J^%&
M#?7$?(KJ!`J+Z@4+S>D&JW0!`)08ZP`*!IQ)\0`+\`X:ZP0(0.I'$$OQ``G=
MZ0"K2NH`"ACK"@1)\0`%H$:<!T3JD@0'E*E&S>D4B2!&E`<&E$)&W>D&10`C
MW.D`B4_J0QL$0PU#2^K2:\WX`+`@1BE&W>D.14_J0AK-Z0@!O0=$0`_VY`'1
MZ0`!1>J6!1#K"`!!ZPD!@$:)1MWI$`%@0`1&#)@8ZP``2?$``1#K!`A!\0`)
MV0X!D;0'W>D``;D(0.H*`!CK``M)\0`,7D;91N)&#?7(?$3J!0O-Z1":W.D`
MB47J`0S=Z0A%3_``"E=&S>D,O(3J"P0/]FP+V^D`JX7J#`4.F!KK"`I/ZD<1
M2^L)"T'JUF'01@&1V4;=Z12KF0@-]<Q\BNH$"HOJ!0O-Z0:K=`$`E!CK``H&
MG$GQ``OP#AKK!`A`ZD<02_$`"=WI`*M*Z@`*&.L*!$GQ``7<Z0")HD:<!T3J
MD@0'E*M&S>D4JR!&E`<&E$_P``O=Z09%6T921D_J0QL$0PU#2^K2:\WX`+`@
M1BE&W>D,14_J0AK-Z0X!O0=$0`_RO''1Z0`!#?70?$7JE@40ZP@`0>L)`8!&
MB4;=Z1`!8$`$1@B8&.L``$GQ``$0ZP0(0?$`"=D.`9&T!]WI``&Y"$#J"@`8
MZP`*2?$`"]%&VD;-Z0B:3_``"DY&5T;<Z0")1.H%"D7J`0L/\E1QT>D``51&
M7480ZP@`W>D.JT'K"0'=Z12)BNH$"LWI``&(Z@H(#)C-Z1!%?0'"1MWI`(E%
MZM9E^0X8ZP`(`)48ZPH``9%T`9T(@$;=Z0`!3^J#>VJK2^J2"R!#3^J">@`A
MT^D`(QCK``B)1@`@`"'-Z0`!2NH+`$OJ!0'=Z1!%QD:"1HM&S>D,JTA&#_+$
M;-SI`+Q``0&0A.H*!!OK`@M"1M,.`9I81D/J21,&DP`EE$8.FDSJV&S-^`3`
MW>D(O(`80D;-Z12)B^H$"U(!$.L+``"22D;=Z0"\TPX'DP1&W>D&`4_JAWE/
MZH9X0.H+`$GJE@DD&,WI`$5(Z@D%NPA)Z@,&;*FK1MWI#$6T1LWI#+Q$Z@L)
M1>H&"M'I``$`)4I&4T;91D_P``K-Z0B:3_``#`_R*&K:Z0":W>D4J\WI#D49
MZP`)5$840!":748=0`";&>L"",WI%$7=Z0@2`"+=Z0Y%VPY/\``)#$``(<WI
M!A(&D]WI%"-NJP:9(D/=Z0!%$NL(`%I&0>I%$0:1Z0X'D8!&W>D&`68!E0<P
M0T7JF@48ZP`"4$:$!]/I``&01EI&1.H%"I<(W>D,(T7J!PO-Z1"K3^I)%T+J
M"@)#Z@L#TT;-Z0R\#_*$6]OI`*M'ZMAGW>D`O$_J2!8:ZP`*W>D(10OJ`@O=
MZ0P24$8,Z@,,S>D4O`Q`W>D.JT_JV&,`(0`BS>D&$D_JV6$&DQKK``K=Z10C
M#?4`?`:7!Y$B0]WI!@$:ZP(*`9LP0QKK``+=Z0"KG0<`FT7JF@621MWI`!*>
M"'"K1NJ+=D_P``O-Z0"KC`>7"-/I``%$Z@8"1>H'`]WI"*L41D_JF0<=1MWI
M$"/-Z1!%3_``"R)#*T,`)<WI#D4/\LA%U>D`10/J"04D&"!&`NH(!-WI#A(:
MZP`*S>D410`BW>D,-`M``"'-Z082W>D``1Q&PPX&D]WI%",-1@:9<JLB0P1&
M$NL*`$'J11$&D>D.!Y$"1MWI!@%F`4_JB75/ZHAT,$-%ZI@%1.H%"$7J!PD2
M&`_R5$75Z0!%T^D``4_J2Q>21MWI$",D&,WI$(E-04+J"`(@1D/J"0,I1MWI
M`$5/\``)S>D(B11`'4#-Z11%1^K:9]WI##1/ZDH6&QA,0=WI"!*81D_JVF.A
M1MWI#D4,0!5``"$`(LWI!A)/ZMMA!I/=Z10C!Y$B0RM#$NL(``:70^L)`=WI
M`(G-Z0P!W>D&`4I&3_``"94'W>D,(S!#=*L2&-WI``%%ZI@%D$:$!X\(1.H%
M`M/I``%%Z@<#3^I)%Q1&1^K89QU&W>D0(\WI!D5/ZD@6(D,K0P`ES>D,1=VE
MU>D`10/J"P4D&"!&`NH*!,WI$$7=Z0Y%W>D,(P`C)!@@1MWI"$5/ZHMU%$``
M(LWI`"-/ZMAC`)-%ZIH%W>D0(W:K`)=/ZIL'(D-/ZMED@!@!E$_JBG1%Z@<+
M`D;=Z0`!1.H%"@`A,$-=1A(85$;-Z1!%3^J9!Q!&S>D``=/I``'=Z08CW>D(
MJT_P``LB0RM#`"7-Z0Y%MZ75Z0!%`^H)!208($8"Z@@$W>D.$AKK``K-Z11%
M`"+=Z0PT"T``(<WI!A+=Z0`!'$;##@:3W>D4(PU&!IEXJR)#!$82ZPH`0>I%
M$0:1Z0X'D0)&W>D&`68!3^J)=4_JB'0P0T7JF`5$Z@4(1>H'"1(8FZ75Z0!%
MT^D``4_J2Q>21MWI$",D&,WI$(E-04+J"`(@1D/J"0,I1MWI`$5/\``)S>D(
MB11`'4#-Z11%1^K:9]WI##1/ZDH6&QA,0=WI"!*81D_JVF.A1MWI#D4,0!5`
M`"$`(LWI!A)/ZMMA!I/=Z10C!Y$B0RM#$NL(``:70^L)`=WI`(G-Z0P!W>D&
M`4I&3_``"94'W>D,(S!#>JL2&-WI``%%ZI@%D$:$!X\(1.H%`M/I``%%Z@<#
M3^I)%Q1&1^K89QU&W>D0(\WI!D5/ZD@6(D,K0P`ES>D,162EU>D`10/J"P4D
M&"!&`NH*!,WI$$7=Z0Y%W>D,(P`C)!@@1MWI"$5/ZHMU%$``(LWI`"-/ZMAC
M`)-%ZIH%W>D0(WRK`)=/ZIL'(D-/ZMED@!@!E$_JBG1%Z@<+`D;=Z0`!1.H%
M"@`A,$-)I=7I`$42&,WI$*M/ZID'$$;-Z0`!T^D``=WI!B,D&$+J"@)#Z@L#
M`^H)!2!&`NH(!,WI%$7=Z0A%3_``"\WI#JM/\``+)!C=Z0X2`"*B1MWI#$4,
M0``AS>D&$MWI``'##@:3W>D4(PU&!IE^JR)#!$82ZPH`0>I%$0:1Z0X'D0)&
MW>D&`68!3^J)=4_JB'0P0T7JF`5$Z@4($AC3Z0`!1>H'"=WI$#221LWI$(E/
MZDL70^H(`T3J"01/\``)S>D(B1I&(T;=Z0!%1^K:9P_R6`G9Z0")3^I*%A1`
M'4#-Z11%&.L`"-WI#$5)ZP$)W>D(`4_JVF,4ZP@$3_```D7K"06@1JE&W>D.
M10U``"'-Z082!$`&DT_JVV$)X*_S`("AZ]EN`````-R\&X\`````W>D4(P>1
M(D,K0Q+K"``&ET/K"0'=Z0")S>D,`=WI!@%*1D_P``F5!]WI#",P0T7JF`42
M&-WI``$`)I!&A`>/"$3J!0)%Z@<#`"7-Z0!6W>D05AQ&$T;-Z08T)D,50]SI
M``%/ZDD4*D8S1MWI!E8`)C=&`90-]0)\+D8/]NQEU>D`10/J"P4D&"!&`NH*
M!,WI#$7=Z0Y%3^J+=0&;1>J:!208W>D(`4/JV&,!D]WI#",P0,WI#F=/ZD@6
M`D,`EA893^K88$#J21!/ZHIT,D;=Z0!G3^J;`0`G!D-%Z@$#DAG<Z0"K&48-
M]01\%D9$Z@4"S>D`9P`E$$;=Z08CS>D0`01&`D,+0P_V8&'1Z0`!`^H)`<WI
M#$5/ZID'W>D`11#K"@!/\``+@D8"Z@@`S>D``2!&W>D(-"E&W>D,10U&$^L*
M`YI&W>D.(P`C(D`41@`BS>D&(\,.!I/=Z0`C`",&F2)#!$82ZPH`0>I%$0:1
MZ0X'D0)&S>D`14_JB77=Z08!9@%%ZI@%3^J(=$7J!PE$Z@4(,$/=Z1!61T82
M&#U#1NH)!I)&W.D``2I&`"3-Z08T,T8/]K16UND`5LA&3^I+%,WI$'@M&$_P
M``@'E$Y!S>D(>"A&W>D`B3%&#?4&?$1&34840!U`S>D`1=WI#E8'FRT83D'=
MZ0P!+$9#ZMIC-4;=Z0AG!Y/=Z0`C,$`Y0$_J2A8"0P:6"T,6&4/K!0=*1LWI
M`&=/ZMI@W>D&9T#J2Q"5!]WI`",&0\WI`(F2&=WI`&=%ZI@%3_``"9!&W>D0
M([0'N0A$Z@4&1>H!!P`E,D,P1CE&-$;-Z1`!S>D.13M#W.D``4_J21</]NQ%
MU>D`10/J"P5'ZMAG3^I(%@`9`NH*!,WI!D4-]0A\W>D,1=WI#B,`(R08($;=
MZ0A%3^J+=11``"+-Z0`C3^K88P"31>J:!=WI!B,`(P"73^J;!R)#3^K99(`8
M`91/ZHIT1>H'"P)&W>D``43J!0H`)#!#W>D05A(8S>D&-$;J"P8`(1!&S>D`
M`3-&`";<Z0`!1>H*!<WI$*NS1MWI`&<J1LWI#*L-]0I\?`$'E`_V/$75Z0!%
M)!A-02!&`NH(!"E&`^H)!<WI`$7=Z0A%!YLD&$U!W>D.`4/JUF,'D]WI`",`
MZ@H``>H+`;)&`D,+0_`.=@$&EA89NT9`ZD<00^L%!\WI"&?=Z09G3^J)==WI
M""-%ZI@%!D-/ZHAT3^J9`9(91>H!!T3J!0;=Z1!%W.D`B3!&-$,]0\WI`*N2
M1BM&(D8`)31&S>D(13E&#_:@-=7I`$5/\``+S>D0`4_J2Q<4ZP@$W>D.`47K
M"05'ZMIGH$80ZP@`J4;=Z0!%0>L)`4_J2A840!U`B4;-Z11%W>D($D_JVF/=
MZ0Q%#?4,?`Q`%4``(0`BS>D&$D_JVV$&D]WI%",'D2)#*T,0&`:70^L)`=WI
M`(G-Z0X!W>D&`4I&3_``"94'W>D.(S!#1>J8!1(8W>D``0`FD$:$!X\(1.H%
M`D7J!P,`)<WI`%;=Z1!6'$831LWI!C0F0Q5#W.D``4_J210J1C-&W>D&5@`F
M`90W1@WU#GPN1@_VQ"75Z0!%`^H+!0&;)!C-Z1!G0^K88P&3($8"Z@H$S>D.
M1=WI#$5/ZHMUW>D.(T7JF@4D&-WI"`%/ZIL!,$!/ZD@6`D,`EA893^K88$#J
M21!/ZHIT,D;=Z0!G1>H!`]SI`*L&0P`GDAD91D_P``L-]1!\%D9$Z@4"S>D,
M9T_JF0<01MWI!B/-Z10!`D,+0P`AS>D.`0_V+"'1Z0`!`^H)`=WI#$40ZPH`
M@D8"Z@@`S>D&`2!&*4;=Z0A%W>D.(P`C%.L*!*)&W>D010U&%$``(LWI`"/#
M#@"3W>D&(P`C`)DB0P1&$NL*`$'J11$`D>D.`9$"1D_JB77=Z0`!9@%%ZI@%
M3^J(=$7J!PE$Z@4(,$/=Z116$A@`),WI!C1%Z@@%1NH)!I)&7$8J1C-&148`
M)LWI%%9D`=WI#&<'E,WI`*L]1AU`-$840"M&`)W<Z0`!(D8/]G`;V^D`JPWU
M$GP'G!KK``I$ZM5E!Y7=Z1!%2^L!"]WI#@$4ZPH$1>L+!<WI"$5$1@`E($`I
M0-WI`$5`Z@(*0>H#"V$!!I'=Z0@!X@Y"ZD42ZPX0ZPH`3^J'=4'K"P'=Z0:K
M2NH""DOJ`PO-Z0:KLD961KM&L@@&GD7JF@5"ZHMRAAE!\0`'S>D&9U9&7T:T
M![L(W>D&9P`G.49%Z@,'1^H)!=SI`+P/]L@*VND`FC!&1.H"!CM&&^L)"T;J
M"`1/\``)S>D,13)&7$;-Z0@CRT;=Z0PC3.L*#-WI`(E/`;)&1^K09P+J"`(#
MZ@D#W>D.B<WI&*L8ZP0(W>D414GK#`G-Z0R)-$`%Z@L%%$,=0]WI#"-&`4?J
M!@@2&6M!$NL("D/Q``L`(M%&VD;=Z0"\S>D.FD_P``K-Z0":8T:?!UM&G@=C
M1IT(#?44?`&;1^J;!]SI`(E&Z@<*1^H%"P_V&`?7Z0!GW>D(10WU%GS-Z0BK
M3^I#&P";%NL(!D?K"0?=Z0:)A.H*!(T(2^K3:P`CS>D&(XCJ!`@`FP&:1$;=
MZ12)VPX&DP";&.L&",WX&+!)ZP<)&.L$"$_J@7=/ZD,:3^K28P>32?$`"<WI
M#(E'ZI`'W>D&B88'W.D``4?J!0Q(Z@H(W>D,JQKK"`I+\0`+T4;:1D;J!PO=
MZ0A6R$;-Z0R\A>H+!=WI#KS-Z1":3_``"BY&B^H&"P_R8'75Z0!%T49>1D_J
M2A/=Z1BK)!A-04/JV&,:ZP0*!Y-/ZD@3!I,`FTOK!0L:ZP8*3^J"=4OQ``M/
MZMA@1>J3!0";5D9?1MWI!JM`ZDD0G`>1"$KJ``I%Z@$+%NL*!@WU&'Q$Z@4*
M1_$`!UE&S>D.9U!&W.D`(P_RZ&O;Z0"K`"?=Z0Q%#?4:?!KK`@H(FDOK`PO-
MZ08!1$``(0`@S>D``7D!4$8!D5E&W>D0JX`8`9M!\0`!BNH$"O(.0^K68XM&
M`9-41G$!`!D`D4OQ``'=Z0"K0NI'$D_JF0-*Z@(*$.L*!$_JB'!!\0`%3^J)
M<4'JF`'=Z0:)0.H!"D'J`PN(Z@H(W.D``<WI"*L/\E1KV^D`J\WI$$4`)1#K
M"@!/ZD430>L+`4/JU&,!DXM&W>D.$@R:@>H(`8(8B$9/ZD01`)%+\0`#DD;B
M#AKK"`#=Z0"K0NI%$D/Q``%*Z@(*NP@0ZPH(3^J&<$'Q``FY!T'JE@'=Z0AG
M0.H!"T'J`PS-Z0R\#?4<?$_P``K-Z0Z)W.D``=%&ANH+!D_J2A,/\L1;V^D`
MJT/JV&,!DPWU'GP0ZPH`0>L+`8M&W>D0$@::<4""&`Y&3^I($0"12_$``Y)&
M3^K88AKK!@#=Z0"K0NI)$D/Q``%*Z@(*JP@0ZPH&3^J$<$'Q``>I!T'JE`$/
M\F1;V^D`JT#J`01!Z@,%S>D09P`G(D8K1MWI#$7-Z08C>P'<Z0`!5$!#ZM9C
M`9,0ZPH`#?4@?$'K"P&+1MWI#A((FF%`@A@,1D_J1A$`D4OQ``.21O(.&NL$
M`-WI`*M"ZD<20_$``4KJ`@I/ZID#$.L*!$_JB'!!\0`%3^J)<4'JF`'-Z0Y%
M0>H#"@`E0.H!"0`B448`(P_RS$O;Z0"K2$;-Z0`C:P$!D]SI`"/=Z0:)$NL*
M`LWI"`%#ZPL#B.H`"))&W>D0$@R:FT:!Z@@!`9L:ZP("0^K48XA&`9-/ZD01
M`)%+\0`#DD;B#AKK"`#=Z0"K0NI%$D/Q``%*Z@(*NP@0ZPH(3^J&<$'Q``FY
M!T'JE@'=Z0AG0.H!"T'J`PS-Z0R\#?4B?$_P``K-Z1")W.D``=%&ANH+!D_J
M2A,/\B1+V^D`JT/JV&,!DPWU)'P0ZPH`0>L+`8M&W>D.$@::<4""&`Y&3^I(
M$0"12_$``Y)&3^K88AKK!@#=Z0"K0NI)$D/Q``%*Z@(*JP@0ZPH&3^J$<$'Q
M``>I!T'JE`$/\L0[V^D`JT#J`01!Z@,%W.D``0WU)GPB1LWI#F<0ZPH`3_``
M!RM&0>L+`=WI#$7-Z08C>P%40(M&0^K68P&3W>D0$@B:84""&`Q&3^I&$0"1
M2_$``Y)&\@X:ZP0`W>D`JT+J1Q)#\0`!2NH""D_JF0,0ZPH$3^J(<$'Q``5/
MZHEQ0>J8`<WI$$5!Z@,*`"5`Z@$)`")11@`C#_(L.]OI`*M(1LWI`"-K`0&3
MW.D`(]WI!HD2ZPH"S>D(`4/K"P.(Z@`(DD;=Z0X2#)J;1H'J"`$!FQKK`@)#
MZM1CB$8!DT_J1!$`D4OQ``.21N(.&NL(`-WI`*M"ZD420_$``4KJ`@J["!#K
M"@A/ZH9P0?$`";D'0>J6`=WI"&=`Z@$+0>H##,WI#+P-]2A\3_``"LWI#HG<
MZ0`!T4:&Z@L&3^I*$P_RA"O;Z0"K0^K88P&3#?4J?!#K"@!!ZPL!BT;=Z1`2
M!IIQ0((8#D9/ZD@1`)%+\0`#DD9/ZMAB&NL&`-WI`*M"ZDD20_$``4KJ`@JK
M"!#K"@9/ZH1P0?$`!ZD'0>J4`0_R)"O;Z0"K0.H!!$'J`P7<Z0`!#?4L?")&
M*T80ZPH`W>D,14'K"P'-Z08C5$#-Z1!GBT;=Z0X2")H`)V%`>P&"&$/JUF,,
M1@&3DD9+\0`#<0$:ZP0``)%/ZM9BW>D`JT+J1Q)#\0`!3^J9`TKJ`@H`(A#K
M"@1/ZHAP0?$`!4_JB7%!ZI@!S>D.14'J`PH`)4#J`0D`(U%&S>D`(P_RB!O;
MZ0"K:P$!DTA&W.D`(]WI!HD2ZPH"S>D(`4/K"P.(Z@`(DD;=Z1`2#)J;1H'J
M"`$!FQKK`@)#ZM1CB$8!DT_J1!$`D4OQ``.21N(.&NL(`-WI`*M"ZD420_$`
M`4KJ`@J["!#K"@A/ZH9P0?$`";D'0>J6`=WI"&=`Z@$+0>H##,WI#+P-]2Y\
M3_``"LWI$(G<Z0`!T4:&Z@L&3^I*$P_RZ`O;Z0"K0^K88P&3#?4P?!#K"@!!
MZPL!BT;=Z0X2!IIQ0((8#D9/ZD@1`)%+\0`#DD9/ZMAB&NL&`-WI`*M"ZDD2
M0_$``4KJ`@JK"!#K"@9/ZH1P0?$`!ZD'0>J4`0_RB`O;Z0"K0.H!!$'J`P7<
MZ0`!#?4R?")&*T80ZPH`W>D,14'K"P'-Z08C5$#-Z0YGBT;=Z1`2")H`)V%`
M>P&"&$/JUF,,1@&33^I&$0"12_$``Y)&\@X:ZP0`W>D`JT+J1Q)#\0`!3^J9
M`TKJ`@H`(A#K"@1/ZHAP"N``OZ_S`(#<O!N/`````-;!8LH`````0?$`!4_J
MB7%!ZI@!S>D014#J`0E!Z@,*`"4`(TA&44;=Z0:)#_(P.]OI`*O-Z0`C:P$!
MDXCJ``C<Z0`CS>D(`1+K"@)#ZPL#DD;=Z0X2#)J;1H'J"`$!FQKK`@)#ZM1C
MB$8!DT_J1!$`D4OQ``.21N(.&NL(`-WI`*M"ZD420_$``4KJ`@J["!#K"@A/
MZH9P0?$`";D'0>J6`=WI"&=`Z@$+0>H##,WI#+P-]31\3_``"LWI%(G<Z0`!
MT4:&Z@L&3^I*$P_RD"O;Z0"K0^K88P&3#?4V?!#K"@!!ZPL!BT;=Z1`2!IIQ
M0((8#D9/ZD@1`)%+\0`#DD9/ZMAB&NL&`-WI`*M"ZDD20_$``4KJ`@JK"!#K
M"@9/ZH1P0?$`!ZD'0>J4`0_R,"O;Z0"K0.H!!$'J`P7<Z0`!#?4X?")&*T80
MZPH`W>D,14'K"P'-Z0XC5$#-Z09GBT;=Z102")H`)V%`>P&"&$/JUF,,1@&3
M3^I&$0"12_$``Y)&\@X:ZP0`W>D`JT+J1Q)#\0`!3^J9`TKJ`@I/\``+$.L*
M!$_JB'!!\0`%3^J)<4'JF`&B1D'J`PE`Z@$(S>D01=WI#D5!1DI&S>D($DQ`
M8Z/3Z0`CW.D``4_J2QE)ZMII3^I*&(`83^J'=5E!S>D``=WI!A)%ZI8%#)H-
M]3I\84`,1MWI``'-^`"0@!A!\0`!`AE!\0`#S>D&(T_JVV,!D]WI`".T![D(
M`"-"Z@@"W>D&B47J`0G<Z0!G&.L""$)&1.H%",WI`"-,1@`B`"/-Z08C0T;=
MZ0")S>D,-$I&4@$'DMWI"!)90&)`!YL\I=7I`$4(1D/JV&,11J090D;=Z1")
M)D;4#HCJ``B)Z@$)#IK=Z0`!S>D0B1;K`@@0F@>30P$&DT3J0108ZP((3^J+
M<=WI!B-!ZIH!3^J*<")#0.H!"AJ9&.L""-WI`B,`(Q+K"`+=Z1:)P>D`(]WI
M`#03ZP@#1.L)!)A&H4;-Z0")O9W=Z0IX#)O_&!N;2/$`",WI`GC=Z1)X'&@(
MF_\8W>D$(TCQ``C-Z09XW>D"9P`GW>D`B4_P``D2ZPH"I4+!Z09G3_```\'I
M`HD:GMWI!@%/\``!QND$(\;I"`$#T0WU/WV]Z/"/_/<H[0"_K_,`@-;!8LH`
M````+>GX0R!+>T0`*#C0'TJ;6-/X`)"Y\0`/,]`#>+/Q/048OP$E`"L(OP`E
MK;G9^`!`?+$'1HA&3D8J1CE&($;\]P;N$+EC73TK#]!6^`1/`"SRT2!&O>CX
M@P5&%?@!/P`K&+\]*_G1+1K@YP$UINL)!BQ$MA#(^`!@($:]Z/B#!$;GYTQ&
MY><`OUIE`0!(`0``\+6#L!5/!4852VQ&?T3^6#-H`9,A1BA&__>J_["Q$4L`
MF/M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&*$;_]Y3_`"CHT0&:
M,VB:0@'1`[#PO?SWJNS$9`$`&`$``$@!```MZ?!/#$;?^%R1A;!62P5&^40*
M>%GX`V`]*@B_`30S:"!&`Y/\]PKM`JD'1BA&__=K_X!&`"A4T/SW`.VX0D?2
M2DL"FEGX`Y!/ZH((*WBS\3T`&+\!(``K"+\`(#BQ*$80^`$_`"L8OSTK^=%`
M&P(WV?@`H#A$_/>^[$KX"```*&O0V?@`(&D<`I@K>%+X(``]*QB_`"L#<`G0
M0AP1^`$[$$8`*QB_/2L"^`$[]M$"1CTC`W`4^`$[`O@!/P`K^=$`(`.:,VB:
M0DK1!;"]Z/"/"/'_,!3X`3L`^`$_`"OYT>[G(DM9^`.0V?@`L-OX`#"#LUM&
M`.!01E/X!"\`\0$*`"KXT0,P@``92GI$$VBSN0$C$V#\]V[L`9#PL4_JB@A9
M1D)&_/?8ZP&;R?@`,`KQ`0(`(4/X(A#-^`B@AN<!1EA&_/<6[`-&R?@``"BQ
M3^J*".SGFD8((-;G3_#_,+#G_/?RZUAD`0`8`0``2`$``.YD`0`S2S1*>T0M
MZ?!/G["<6"-H'9,0L0-X!D8SN1V:(VB:0E31'["]Z/"/_/<>[`=&`"CST-_X
MI(#?^*20W_BDH/A$^43Z1#A&_/>T[*BS`/$3!4%&*$;\]VCK`"CST$E&*$;\
M]V+K`"CMT#!&_/<N[(-&*$;\]RKL6$0",/SW`NQ31D_P_S(!(0&5`):#1OSW
M.NQ91@*J`R#\]Y[L`3!81@70!IL#]'!#L_6`3PS0_/>@ZUA&_/=>Z\7G.$;\
M]ZKL,$;\]VCKJ>?_]YO_\>?\]X+K\&(!`!@!``#F$@``Z!(``.H2```42P%&
M,+5[1!-,G;`%1@,@:D8<62-H&Y/\]X+L<+D$FP/T<$.S]2!/&+^S]8!/!]`;
MFB-HFD(+T1VP,+T`(/?G*$8"(?SW,.RP^H#P0`GOY_SW3NL*8@$`&`$``"WI
M\$.M]8!=)DR#L"9+#?6`5GQ$`:V`1B1(YU@$-HE&0/;_<BE&>$0[:#-@_/=8
MZQ]+`"@IW48>XUBJ71QHTK$&1C)&+R$H1OSW^NNHL2!&_/=$[#-&*D9!1OSW
M$.P-]8!3!#,::#MHFD(8T0WU@%T#L+WH\(,`+N/1($;\]R[L2D9!1OSW)NOI
MY^-8'&@@1OSW).Q*1D%&_/<<Z]_G_/?ZZ@"_HF$!`!@!``#.$0``(`$``!"U
M"$P(2WQ$XU@8:/SW#.P&2@=+!TFB6'M$>42]Z!!`_/>"N_I@`0`@`0``'`$`
M`.@0```V$0``#4L.2GM$$+6"L)Q8(&C\]_#K__?9_R!H_/?JZPA+`"$(2GM$
MS>D`,0=)>D1Y1/SWC.L"L!"]`+_$8`$`(`$``.(3```W#0``"!$``"!*(4MZ
M1/"UK?4`7=58A[`-]0!2'4P4,@WU@%8K:'Q$$#838/SW".L92T'R`0(!(7M$
MS>D`!`.L($;\]RCK($8Q1D_T@%+\][#J!!X6VV`<_/?:Z@=&*+$Q1B)&_/=8
MZ@`C.U4-]0!3.$84,QIH*VB:0@71#?4`70>P\+T`)_'G_/=LZGA@`0`8`0``
M[A```-`0``#_][2_5TM82GM$+>GP3ZWUA%V;6(.P!$8-]812!J]32`23!#(;
M:`U&>$0Y1A-@__<K_2\A!D8@1OSWS.J8L4Q((49X1/_WG/T@1@WUA%,$,QIH
M!)L;:)I"0/""@`WUA%T#L+WH\(\@1OSWJ.I!27E$@48H1OSW"NL`*.#0/DL%
M1M_X^+![1`63*WC[1-_X\*#Z1``K0-`NL2E&,$;\][[I`"@_T"A&_/>*ZD(>
MJQBJ7"\J!M$`(1EP`3@3^`$M+RKYT`GQ`0,81+#U@%^WV@WQA`@L2@$A`I1Z
M1%-&`9)`1D_T@%(`E?SWB.HZ1D%&`R#\]^KJ*+D[:0/T<$.S]0!/&=`A20`@
M>43\]\#J!48`+970*W@`*[[1YK%91C!&_/=^Z="Y&4D`('E$_/>PZ@5&`"WN
MT8/G`2%`1OSWHNH`*-_1$TA!1GA$__<:_4!&_/>VZ7KG!9T!(+/G748!(+#G
M_/>RZ>!?`0`8`0``5!```$80```J$```E`\``(X/```,$```S`\``)(/``!P
M#P``0@\```-X.[%"'"\K"+\01A+X`3L`*_C1<$<`OSBU^+$%>`1&Y;'\]P+J
M`3@B&)1"#-(C7"\K-=%3'@+@$7@O*3#1HT(:1@/Q_S/WT91"#=$O+330'4B]
MZ#A`>$3\]V2Y&TB]Z#A`>$3\]UZY`3H#X!%X+RD$T1I&E$("\?\S]],2&Y,<
ML_6`7XB_`"`)V!%((48!,D_T@%-X1`1&_/<^Z2!&.+U3'@+@$7@O*=[0G$(:
M1@/Q_S/WTY1"R=#6YP9(O>@X0'A$_/<ON0"_N@X``"(.``!D7P$`Q`T``"WI
M\$&,L$9,`JU&3WQ$1DX,-']$W_@4@0_,^$2_60&N#\4/S-?X`,`/Q21H0$C-
M^"S`>$0L@/_W.?P^2'A$__<U_#U(>$3_]S'\/$AX1/_W+?P[2'A$__<I_#I(
M>$3_]R7\.4AX1/_W(?PX2'A$__<=_$!&__<:_#5(>$3_]Q;\-$AX1/_W$OPS
M2#%&>$3_]\7[&+$!1D!&__<\_"](,49X1/_WN_L@L0%&+4AX1/_W,?PL2#%&
M>$3_][#[B+$!1BE(>$3_]R;\*$DI2'E$>$3_]R#\"YH[:)I"'M$,L+WH\($D
M2#%&>$3_]YC[>+DB20HB#?$9`'E$_/>VZ0`HX]$>2`WQ(P%X1/_W!/S<YP%&
M&TAX1/_W_OO6Y_SWH.@`OW`-``!J70$`&`$``'(.```*#@``#`X```P.```0
M#@``$`X``!@.``"L#0``%`X``!X.``":#0``&`X``!@.```@#@``(@X``$X-
M```\#@``E@T```(.```&#@``>@T``&X-```221-*>4032Q"U>T2,6(*P&&@C
M:`&30QP%T`&:(VB:0A+1`K`0O0Q(:49X1/_W-/LPL0!X,"@8OP`H%+\!(``@
M!DM[1!A@Z.?\]T;H]%L!`!@!``!"70$`T@P```I=`0`(M?OW_._[]^[O`+$`
M:`B]($LA2GM$+>GP08:PG%@%1AY.!*DC:'Y$,$8%D__W!/LI1A"S`W@'1ONQ
M^_?"[P"[*$;\]Y3H@$8X1OSWD.A`1`(P_/=HZ!)+3_#_,@*7>T3-Z0!3#TL!
M(7M$@$;\]YSH048P1O_W7/L#X`M(>$3_]U?[!9HC:)I"`M$&L+WH\('[]_+O
MA%L!`!@!```"#0``Z@L``.0+``"L#```+>GP3ZWU`4W?^`!'I;#?^`"7#?7(
M>WQ$W_CX-B(=")#Y1*OQX`8'R@3Q$`P&EJOQ^`=9^`,P!/$H"JOQ[`@,K8?H
M!P`'D[SH#P`'G`_&#?4!0YSH`P",,]3X`."&Z`,`FN@'`,/X`."(Z`<`*4;?
M^*@&>$3_]XKZ(+$#>`1&`"M`\*V`__=F_P9&`"@`\*Z`,$;\]Q;H0``!,/OW
M[N\S>()&@['?^'2&5$;X1`"3($9#1D_P_S(!(0(T_/<@Z!;X`3\`*_+16_C@
M#+"Q!IP"X%3X!`^(L2E&__=8^@9&`"CVT`-X`"OST/_W^/L`*._0,$;[]V;O
M!$:8N0`F5_@F0``L:M`C>``K9]`@1@$V__?E^P`H\M`@1OOW4N\`*.W0!$8@
M1M_X^'7[]\KO?T0&1E!&^_?&[P9$!O($1C!&^_><[]_XX#5/\/\R`2%[1,WI
M`3??^-0US?@,H'M$`)2`1@:0^_?,[T!&3_3@<?OWVN\!,`71^_>\[P)H$2I`
M\&F"*D8&F0,@_/<ZZ`1&*+DK:0/T<$.S]8!/1]#?^)`E`2$(FT_P``I9^`(`
M!IH;:`"2W_A\)0!H>D3[]]+O#?4!0U!&C#,::`>;&VB:0D#PAX(-]0%-);"]
MZ/"/`"2AY__WP?X@1OOW[.Z"1N?G!$8(ZX0&!#Y6^`0/<+$I1@$T__?%^0`H
M]M`#>``K\]#[]]CN`"CLT`9&.^<-(-_X&&7[]RSO4R-^1()&/.>O:?OWD.Z'
M0K+1*VG#\P@#L_7@?ZS1,$;[]QKO*4:"1M_X[`1X1/_WG/D`*'[0")L=:/OW
ML.X!1BA&__=0_`5&`"AST"A&^_<F[P,H!D80V=_XP!0$."A$>43[]TSN0+D$
M+@#PO8$N1!;X!3PO*P#PMX'_]RK^,+D!1BA&^_?B[@F0`"A5T=_XC!3?^(P$
M>43?^(QD>$3?^(B$__?>^7Y$^_?N[M_X@#0&G4_P_S)[1-_X>!0!D[%&W_AT
M-'E$W_AP=/A$`Y%[1`"5`2%_1"Y&`I!01OOW_NX3X/OW].X#:!$K%M'[]\SN
M`30$ERI&`Y1#1LWX!)`!(0"6`I!01OOWZ.Y/].!Q4$;[]_CN0QP%1N/0!IC[
M]Q3NW_@<!%%&>$3_]YOY4$;_]PC^,N<(FQUHB.>K\00#;_`1`@B3`B0=1@"4
M3_#_,_OW:NXI1@8B"9C[]^3M&_@$/!NY:WA#*P#P=($`)``B`",`E`F8J_'(
M!?OW5N[1H='I``'1H]/I`".L9\7I`@&K\9`!"Y'/H='I``'%Z00CSJ/3Z0`C
MQ>D&`<ZAT>D``<7I"",`(@`CS?@HL,7I"B/%Z0PC2^DR`4_T`$+=Z0@0^_>H
M[00>=MW5Z0IGXP!/\``,H$::&;Q%"+^R0D_JY'G5Z0P!DT8"T@$P0?$``5I&
M8T;%Z0HC3^I8<QY&JV]&ZLD"%D9/ZEER-AA"ZP$'Q>D,9P`K3-##\4`("YJ@
M10B9`NL#`*B_H$9"1OOWDNVK;T-$JV=`*[_1")LH1J3K"`281/SW._@_+"K=
M0#P(\8`))/`_`]WX*+`(\4`.F42N\4`&J_&0##!H$#96^`P<9T96^`@L#/$0
M#%;X!#QV10_'\=$H1OSW&O@&\4`.SD7FT:,)S?@HL%H<I.N#%`CK@AA!1D@C
M(D8+F/OWI.VL9X/GW?@@@,?GW>D)"_OW@NZL:JOQD`<N:\3SQ0*`(5,<."NY
M5`#SEX#X&,/Q.`(`(?OW$.XH1B(.A?AS8#,.A?AT((7X=T"%^'`P,PPV"H7X
M<3"%^')@(PPD"H7X=3"%^'9`^_?4_UOXR.RK\40"+&FK\3`&J&FK\0@+U?@(
MP$_J'D%1<$_J'F,I:M_X^(%/ZAQE"_@\/(+X!\#X1-1R%7%/ZAQ%T'-/ZAPL
M57$E#M%T%7(E#(+X!L`D"E5R%4:4<@0.%',$#``*5'.0<S1&"`X0=`@,"0I0
M=)%T@O@#X$_J'BZ"^`+@`>`5^`$_`),@1D-&3_#_,@$A`C3[]Y#MHT7RT0:<
M3_#_,F!(`2%@2WA$`I8#D'M$`)101@&3`".&^"@P6TM[1/OW>NV8Y@B;7F@`
M+C_T1*XP1OOW5.T#*'_V/JY4200X,$1Y1/OW>NP`*`B_-48SYL/Q0`+X&``A
M^_=X[2A&^_=3_SA&."(`(?OW<.U?YPB;`2$U2$_P``H;:%GX```!D@::`))#
M2@!H>D3[]WCMH^4(FYMX02M_](>N")O;>$,K?_2"K@B;&WE(*W_T?:X(FUMY
M12M_]'BN`)1/\/\S"9QO\#D"($;[]\[L")T@1BDB,4PI1OOW1.PP2P:8?$1[
M1`&3+TM/\/\R`)`!(0*54$8#E'M$^_<0[2[F^_=V[`"_B:O-[P````#^W+J8
M`````'94,A``````\.'2PP`````!(T5G`````"I<`0#,6@$`&`$```X+``#J
M"P``?`L``%P*``!""P``*`$``#8+``!H"@``\@H``,8*``#`"0``,@D``.`(
M``","@``T`@``$(+``!X"@``,@L``#@(```<!P``/`@``+8%``!6!P``*@<`
M`$0&``!H!P``Y@0``((&``"72IA)+>GP3WI$A["62P2N`I906`%H`Y`%D=18
M(&C[]S;M!48@:/OW,NV5^&@P,4:`^&DPC4AX1/[WY/X8L0-X,2L`\.F`__?/
M^B!H^_<>[8=)"R,!(GE$^_=6[``H8]"$2@%I>D34^`"@4FC1^!B``2I;W=_X
M`+)/](!I?TO`\B`)^T0`)GM$`24`DRC@`FC;^`@`U/@`H)-H4/@E<`GJ`P.S
M]8!O"+\1:0S04$8!D?OW[.P!F0(C`"():/OW].O4^`"@`48X1OOW9NL`FUMH
M`"A`\)2``34!-JM"0/./@%!&^_?4[$%&`",R1OOWDNP!1@`HR]%B2M3X`*!Z
M1%)H41ZQ0A+1`2H0W5Y.`2501GY$`.`@:/OWNNQ!1OOW9NMS:`$UJT+UW-3X
M`*!01OOWKNQ520,C`2)Y1/OWYNL%1FBQ(&C[]Z+L*VE02AEH>D3[]YCK*VD;
M:)MH6P)LU"!H^_>4[$I)`R,!(GE$^_?,ZP5&>+%'2`*9>$3^]T/^!D8@:``N
M3=#[]X+L*VDR1AEH^_=XZR!H^_=Z[#]-?40&1B!H^_=T[#U)`2)Y1/OWUNL[
M2GI$`48P1OOW9.L@:/OW9NP`(@*9`T8V2(/X:2!X1/[W&/X$1NA@F+%/].!Q
M($;[]]SK0QP1*!B_`2LNV`.;!9H;:)I")]$'L+WH\(\:1G[GJ&C_]SC[!$;H
M8``HY-$E2'A$^_>TZT-X`"L_]!6O$>?[]S3L(4LJ:7M$FV@0:!EH_O>]_ZWG
M(&C[]RCL*VD9:/OWONN*Y_OW_.H820-&&$@B1GE$>$2):`EH^_>0ZUQ3`0`8
M`0``(`$``!8$``"N!0``D%0!`')4`0!N5`$`^%,!`.13`0#4!```P@0``*X$
M``",`@``6%,!`'($``""!```*@(``"H$``#*4@$`H%(!``H$```XM05&__<T
M^0-X!$8[L4(<+RL(OQ1&$O@!.P`K^-'_]TGZ`"T8OP`H`-$XO2MX`"O[T`9)
M($8$(GE$^_>NZP`H\]$H1KWH.$#^][:^,`(```)+>T0;:/OWG[H`OZI1`0`M
MZ?A#!T8,3HA&#$V11GY$^_<@ZGU$=ANV$`K0!#T`)`$T5?@$/TI&048X1IA'
MID+VT;WH^(,`OQ)/`0`(3P$`<$<`OPA`+>D(@+WH`0`"`'!E<FQX<VDN8P``
M`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````"X````N+@``
M)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X
M90!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P``
M`%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'
M````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,
M7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/
M0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$```!,1%],24)205)97U!!5$@`
M4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T
M96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````$%21U8`````&````'!E
M<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#0U````56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)
M4@!435``+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`1'G_?P$`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"I&```:1@```$````!`````0```,L!```!````U@$```$```#@`0``
M`0```"\"```!````B`,```$```"N`P``#````+@2```-````J%X``!D```"$
MK0$`&P````0````:````B*T!`!P````$````]?[_;[0!```%````@`D```8`
M``"@`@``"@```!(%```+````$````!4``````````P```+2N`0`"``````(`
M`!0````1````%P```+@0```1````T`\``!(```#H````$P````@````>````
M"````/O__V\!```(_O__;W`/``#___]O`P```/#__V^2#@``^O__;Q``````
M````````````````````````````````````````````````````C*T!````
M````````Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(`
M`,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``
MQ!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$
M$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02
M``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(`
M`,02``#$$@``Q!(``,02``#$$@``Q!(``,02``#$$@``Q!(``*5>````````
M``````````````````````````````````````````!E7@```````.D5````
M````````````````````!+`!`/____\<8@``Y%X````````$8```"&```!!B
M``!,7P``&&(```````#\80``!&(````````D8@``1T-#.B`H1&5B:6%N(#<N
M,RXP+3(S*2`W+C,N,`!'0T,Z("A$96)I86X@-RXS+C`M,3(I(#<N,RXP`$$R
M````865A8FD``2@````%-RU!``8*!T$(`0D""@02!!,!%`$5`1<#&`$9`1H"
M'`$B`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N
M=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R
M<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N
M=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET
M7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N
M8V]M;65N=``N05)-+F%T=')I8G5T97,`````````````````````````````
M````````````````````````````"P````$````"````5`$``%0!```9````
M```````````!`````````!,````'`````@```'`!``!P`0``(```````````
M````!``````````A````!P````(```"0`0``D`$``"0```````````````0`
M````````-````/;__V\"````M`$``+0!``#L````!0`````````$````!```
M`#X````+`````@```*`"``"@`@``X`8```8````#````!````!````!&````
M`P````(```"`"0``@`D``!(%``````````````$`````````3@```/___V\"
M````D@X``)(.``#<````!0`````````"`````@```%L```#^__]O`@```'`/
M``!P#P``8`````8````#````!`````````!J````"0````(```#0#P``T`\`
M`.@````%``````````0````(````<P````D```!"````N!```+@0`````@``
M!0```!4````$````"````'P````!````!@```+@2``"X$@``#```````````
M````!`````````!W`````0````8```#$$@``Q!(``"`#``````````````0`
M```$````@@````$````&````Z!4``.@5``#`2``````````````(````````
M`(@````!````!@```*A>``"H7@``"```````````````!`````````".````
M`0````(```"P7@``L%X``*@_``````````````0`````````E@````$``'""
M````6)X``%B>```(````#0`````````$`````````*$````!`````@```&">
M``!@G@``!```````````````!`````````"K````#@````,```"$K0$`A*T`
M``0```````````````0````$````MP````\````#````B*T!`(BM```$````
M```````````$````!````,,````&`````P```(RM`0",K0``*`$```8`````
M````!`````@```#,`````0````,```"TK@$`M*X``$P!``````````````0`
M```$````T0````$````#`````+`!``"P``!````````````````$````````
M`-<````(`````P```$"P`0!`L```&!``````````````!`````````#<````
M`0```#``````````0+```#H```````````````$````!````Y0````,``'``
M`````````'JP```S```````````````!``````````$````#````````````
:``"ML```]0```````````````0``````````
